@@ -114,6 +114,18 @@ class ApplicationGraphBuilder(object):
                         config, deployment, event_source, stage_name,
                     )
                 )
+            elif isinstance(event_source, app.KinesisEventConfig):
+                resources.append(
+                    self._create_kinesis_subscription(
+                        config, deployment, event_source, stage_name,
+                    )
+                )
+            elif isinstance(event_source, app.DynamoDBEventConfig):
+                resources.append(
+                    self._create_ddb_subscription(
+                        config, deployment, event_source, stage_name,
+                    )
+                )
         return resources
 
     def _create_rest_api_model(self,
@@ -174,7 +186,8 @@ class ApplicationGraphBuilder(object):
             lambda_function=lambda_function,
             authorizers=authorizers,
             policy=policy,
-            domain_name=custom_domain_name
+            domain_name=custom_domain_name,
+            xray=config.xray_enabled,
         )
 
     def _get_default_private_api_policy(self, config):
@@ -476,6 +489,7 @@ class ApplicationGraphBuilder(object):
             reserved_concurrency=config.reserved_concurrency,
             layers=lambda_layers,
             managed_layer=self._get_managed_lambda_layer(config),
+            xray=config.xray_enabled,
         )
         self._inject_role_traits(function, role)
         return function
@@ -554,6 +568,50 @@ class ApplicationGraphBuilder(object):
         )
         return sqs_event_source
 
+    def _create_kinesis_subscription(
+        self,
+        config,          # type: Config
+        deployment,      # type: models.DeploymentPackage
+        kinesis_config,  # type: app.KinesisEventConfig
+        stage_name,      # type: str
+    ):
+        # type: (...) -> models.KinesisEventSource
+        lambda_function = self._create_lambda_model(
+            config=config, deployment=deployment, name=kinesis_config.name,
+            handler_name=kinesis_config.handler_string, stage_name=stage_name
+        )
+        resource_name = kinesis_config.name + '-kinesis-event-source'
+        kinesis_event_source = models.KinesisEventSource(
+            resource_name=resource_name,
+            stream=kinesis_config.stream,
+            batch_size=kinesis_config.batch_size,
+            starting_position=kinesis_config.starting_position,
+            lambda_function=lambda_function,
+        )
+        return kinesis_event_source
+
+    def _create_ddb_subscription(
+        self,
+        config,          # type: Config
+        deployment,      # type: models.DeploymentPackage
+        ddb_config,      # type: app.DynamoDBEventConfig
+        stage_name,      # type: str
+    ):
+        # type: (...) -> models.DynamoDBEventSource
+        lambda_function = self._create_lambda_model(
+            config=config, deployment=deployment, name=ddb_config.name,
+            handler_name=ddb_config.handler_string, stage_name=stage_name
+        )
+        resource_name = ddb_config.name + '-dynamodb-event-source'
+        ddb_event_source = models.DynamoDBEventSource(
+            resource_name=resource_name,
+            stream_arn=ddb_config.stream_arn,
+            batch_size=ddb_config.batch_size,
+            starting_position=ddb_config.starting_position,
+            lambda_function=lambda_function,
+        )
+        return ddb_event_source
+
 
 class DependencyBuilder(object):
     def __init__(self):
